summaryrefslogtreecommitdiffstats
path: root/libkdepim/addresseelineedit.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /libkdepim/addresseelineedit.cpp
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdepim/addresseelineedit.cpp')
-rw-r--r--libkdepim/addresseelineedit.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libkdepim/addresseelineedit.cpp b/libkdepim/addresseelineedit.cpp
index 63473a6f..2a461376 100644
--- a/libkdepim/addresseelineedit.cpp
+++ b/libkdepim/addresseelineedit.cpp
@@ -109,9 +109,9 @@ static bool itemIsHeader( const TQListBoxItem* item )
-AddresseeLineEdit::AddresseeLineEdit( TQWidget* tqparent, bool useCompletion,
+AddresseeLineEdit::AddresseeLineEdit( TQWidget* parent, bool useCompletion,
const char *name )
- : ClickLineEdit( tqparent, TQString(), name ), DCOPObject( newLineEditDCOPObjectName() ),
+ : ClickLineEdit( parent, TQString(), name ), DCOPObject( newLineEditDCOPObjectName() ),
m_useSemiColonAsSeparator( false ), m_allowDistLists( true )
{
m_useCompletion = useCompletion;
@@ -1047,7 +1047,7 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
TQListBoxItem *item = completionBox()->itemAt( me->pos() );
if ( !item ) {
// In the case of a mouse move outside of the box we don't want
// the tqparent to fuzzy select a header by mistake.
bool eat = e->type() == TQEvent::MouseMove;
return eat;
}
@@ -1047,7 +1047,7 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
if ( !item ) {
// In the case of a mouse move outside of the box we don't want
- // the tqparent to fuzzy select a header by mistake.
+ // the parent to fuzzy select a header by mistake.
bool eat = e->type() == TQEvent::MouseMove;
return eat;